# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Dialogs

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import (
    BatchDataSet,
    OutlierColumns,
    PresentationState,
    ProgressEventArgs,
    QualifierInfoLabelType,
    QuantitationDataSet,
    RowIdBase,
    SampleRowId,
    TargetCompoundRowId,
)
from .Controls2 import IPropertyPage
from .Toolbar import (
    IToolbar,
    IToolbarsManager,
    IToolBeforeDropdownHandler,
    IToolHandler,
    ToolbarsManagerBase,
)
from .Toolbar2 import ITool, IToolHandler
from .UIScriptIF import (
    IAddIn,
    IAddInManager,
    ICompoundsAtAGlance,
    IReviewItem,
    IUIState,
)
from .UIUtils import DefaultEventManipulatorBase

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance

class AddInManager(
    System.MarshalByRefObject, System.IDisposable, IAddInManager
):  # Class
    def __getitem__(self, id: str) -> IAddIn: ...
    def Initialize(self) -> None: ...
    def Clear(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetIDs(self) -> List[str]: ...

class CAGOutlierFilterType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CAGOutlierFilterType
    ) = ...  # static # readonly
    HideOutliers: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CAGOutlierFilterType
    ) = ...  # static # readonly
    ShowOutliers: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CAGOutlierFilterType
    ) = ...  # static # readonly

class CagLayout:  # Class
    def __init__(self) -> None: ...

    DimensionX: int
    DimensionY: int
    FillPeaks: bool
    FitMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    )
    LinkAllXAxes: bool
    LinkAllYAxes: bool
    LinkXAxes: bool
    LinkYAxes: bool
    LinkYAxesVertically: bool
    ManualYScale: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange]
    Normalize: bool
    OrganizeType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType
    )
    OutlierFilterType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CAGOutlierFilterType
    )
    Outliers: List[OutlierColumns]
    Overlay: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    )
    PeakAnnotations: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ]
    QualifierInfoLabelType: QualifierInfoLabelType
    ReviewMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    )
    ShowBaselines: bool
    ShowPeakAnnotationNames: bool
    ShowPeakAnnotationUnits: bool
    ShowRecognitionWindow: bool
    ShowReferenceRT: bool
    ShowUncertaintyBand: bool
    WrapMode: bool

    def CopyFrom(
        self,
        layout: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagLayout,
    ) -> None: ...
    def OutlierExists(self, oc: OutlierColumns) -> bool: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def SaveConfiguration(self) -> None: ...
    def InitConfiguration(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...

class CagSettingsSection(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    DefaultLayout: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PresetLayout
    )  # readonly
    PresetLayouts: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PresetLayoutCollection
    )  # readonly

class CagView(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    CagViewControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagViewControl
    )  # readonly

class CagViewControl(
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ICagViewControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
):  # Class
    def __init__(self) -> None: ...

    CanAutoScale: bool  # readonly
    CanCopyPage: bool  # readonly
    CanCopyPane: bool  # readonly
    CanFitToCalibrationLevels: bool  # readonly
    CanFreezeColumns: bool  # readonly
    CanFreezePanes: bool  # readonly
    CanFreezeRows: bool  # readonly
    CanManualIntegrate: bool  # readonly
    CanNavigateBag: bool  # readonly
    CanShowManualIntegrateWindow: bool  # readonly
    CanUnfreezePanes: bool  # readonly
    CanUpdateRetentionTimes: bool  # readonly
    CanZeroPeakSelectedPanes: bool  # readonly
    ChromSpecProperties: Agilent.MassHunter.Quantitative.UIModel.IChromSpecProperties
    HasData: bool  # readonly
    HasNextReviewItem: bool  # readonly
    HasPreviousReviewItem: bool  # readonly
    LinkAllXAxes: bool
    LinkAllYAxes: bool
    LinkXAxes: bool
    LinkYAxes: bool
    LinkYAxesVertically: bool
    ManualIntegrating: bool  # readonly
    SetupGraphicsContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext
    )
    SynchronizeNavigation: bool
    UpdatingMethod: bool  # readonly

    def FreezePanes(self) -> None: ...
    def MISplitRight(self) -> None: ...
    def FreezeRows(self) -> None: ...
    def SelectAllPanes(self) -> None: ...
    def GetActivePaneScale(
        self, minx: float, maxx: float, miny: float, maxy: float
    ) -> bool: ...
    def MIMergeLeft(self) -> None: ...
    def ShowManualIntegrateWindow(self) -> None: ...
    def GotoPrevOutlierPane(self) -> bool: ...
    def MIDropBaseline(self) -> None: ...
    def GetAutoScaleRangeX(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def UpdateData(self) -> None: ...
    def NavigateBag(self) -> None: ...
    def MovePreviousReviewItem(self) -> None: ...
    def MIApplyISTDRTsToTargets(self) -> None: ...
    def AutoScaleAllPanes(self) -> None: ...
    def MIApplyTargetRTsToQualifiers(self) -> None: ...
    def MISplitLeft(self) -> None: ...
    def ZeroPeakSelectedPanes(self) -> None: ...
    def MoveNextReviewItem(self) -> None: ...
    def SetDimension(self, rows: int, cols: int, updatePaneData: bool) -> None: ...
    def UpdateRetentionTimes(self) -> None: ...
    def SetupGraphicsByParameters(
        self,
        sampleFilter: str,
        sampleOrder: str,
        compoundFilter: str,
        compoundOrder: str,
        organizeRows: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType,
        overlay: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay,
        reviewMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode,
        wrapRows: bool,
        baselines: Optional[bool],
        fillPeaks: Optional[bool],
        normalize: Optional[bool],
        uncertainty: Optional[bool],
    ) -> None: ...
    def UnfreezePanes(self) -> None: ...
    def ExtractGraphics(self) -> None: ...
    def ClearManualIntegration(self) -> None: ...
    def CreatePropertyPages(self) -> List[IPropertyPage]: ...
    def CreateFillPeakBrush(
        self,
        pane: Agilent.MassSpectrometry.GUI.Plot.Pane,
        series: int,
        peakIndex: int,
        color: System.Drawing.Color,
    ) -> System.Drawing.Brush: ...
    def GotoNextOutlierPane(self) -> bool: ...
    def GetSelectedSamples(self) -> List[SampleRowId]: ...
    def MISnapBaseline(self) -> None: ...
    def ExtractAndManualIntegrate(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> None: ...
    def InitConfiguration(self) -> None: ...
    def MIMergeRight(self) -> None: ...
    def MoveReviewItem(self, index: int) -> None: ...
    def EndManualIntegrate(self) -> None: ...
    def FreezeColumns(self) -> None: ...
    def FitToPeak(self) -> None: ...
    def SetManualScaleY(self, miny: float, maxy: float) -> None: ...
    def ManualIntegrate(self) -> None: ...
    def FitToCalibrationLevel(self, lowest: bool) -> None: ...
    def CopyPage(self) -> None: ...
    def ClearAllPanes(self) -> None: ...
    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def FitToPeakHeight(self) -> None: ...
    def NormalizeChanged(self) -> None: ...
    def CopySelectedPane(self) -> None: ...
    def EnsureInitializePanesInPage(self, startRow: int, startCol: int) -> None: ...
    def AutoScale(self) -> None: ...
    def GetSelectedCompounds(self) -> List[TargetCompoundRowId]: ...

    DisplayDimensionChanged: System.EventHandler  # Event
    GraphicsLayoutChanged: System.EventHandler  # Event
    InitializePanesEnd: System.EventHandler  # Event
    InitializePanesProgress: System.EventHandler[ProgressEventArgs]  # Event
    InitializePanesStart: System.EventHandler  # Event

class CagWindow(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    Agilent.MassHunter.Quantitative.UIModel.ICagWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...

    AddInManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.AddInManager
    )  # readonly
    ChromatogramControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagViewControl
    )  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    SetupGraphicsContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext
    )  # readonly
    ToolbarsManager: IToolbarsManager  # readonly

    def GetAddInManager(self) -> T: ...
    def Initialize(
        self,
        dataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator,
        uiState: IUIState,
        chromSpecProperties: Agilent.MassHunter.Quantitative.UIModel.IChromSpecProperties,
    ) -> None: ...
    def ShowSetupGraphicsDialog(self) -> None: ...
    def ShowHelpIndex(self) -> None: ...
    def GetSelectedCompounds(self) -> List[TargetCompoundRowId]: ...
    def GetSelectedSamples(self) -> List[SampleRowId]: ...
    def GetChromatogramControl(self) -> T: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def SetCurrentLayoutAsDefault(self) -> None: ...
    def DeleteDefaultLayoutFile(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def GetSetupGraphicsContext(self) -> T: ...
    def GetToolbar(self, paneId: str, id: str) -> IToolbar: ...
    def ShowHelpSearch(self) -> None: ...
    def ShowHelpContents(self) -> None: ...
    def LoadDefaultLayout(self, loadAllSamplesCompounds: bool) -> bool: ...

class Config:  # Class
    BackColor: System.Drawing.Color  # static
    DefaultShowManualIntegrationHandles: bool  # static # readonly
    SettingsSection: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagSettingsSection
    )  # static # readonly

class DefaultEventManipulator(
    DefaultEventManipulatorBase,
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
):  # Class
    def __init__(
        self, context: Agilent.MassSpectrometry.EventManipulating.Model.IEventContext
    ) -> None: ...
    def OnDoubleClick(self, sender: Any, e: System.EventArgs) -> None: ...

class ExtractTICFromBatch(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase
):  # Class
    def __init__(
        self, index: int, state: PresentationState, batchId: int, sampleId: int
    ) -> None: ...

    RowId: RowIdBase  # readonly

    def Extract(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext,
        extractSignals: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
    ): ...

class ExtractorBase:  # Class
    AnnotationFormat: str
    Index: int  # readonly
    RowId: RowIdBase  # readonly

    def Extract(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext,
        extractSignals: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
    ): ...

class ExtractorCompoundChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase
):  # Class
    def __init__(
        self, index: int, batchId: int, sampleId: int, compoundId: int
    ) -> None: ...

    CompoundMathChild: bool
    RowId: RowIdBase  # readonly

    def Extract(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext,
        extractSignals: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
    ): ...

class ExtractorCompoundMath(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorCompoundChromatogram
):  # Class
    def __init__(
        self, index: int, batchId: int, sampleId: int, compoundId: int
    ) -> None: ...
    def Extract(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext,
        extractSignals: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
    ): ...

class ExtractorQualifierChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase
):  # Class
    def __init__(
        self, index: int, batchId: int, sampleId: int, compoundId: int, qualifierId: int
    ) -> None: ...

    RowId: RowIdBase  # readonly

    def Extract(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext,
        extractSignals: bool,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
    ): ...

class FitMode(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    AutoScale: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly
    FitToHighestLevel: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly
    FitToLowestLevel: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly
    FitToPeak: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly
    FitToPeakHeight: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly
    ManualYScale: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.FitMode
    ) = ...  # static # readonly

class ManualIntegrateControl(
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ICagViewControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
):  # Class
    def __init__(self) -> None: ...

    SetupGraphicsContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SetupGraphicsContext
    )  # readonly

    def GetAutoScaleRangeY(
        self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane, minX: float, maxX: float
    ) -> Agilent.MassSpectrometry.GUI.Plot.PlotRange: ...
    def UpdateData(self) -> None: ...

class ManualIntegrateDialog(
    System.Windows.Forms.Layout.IArrangedElement,
    IToolHandler,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(self) -> None: ...
    def Execute(self, tool: ITool, objUIState: Any) -> None: ...
    def SetState(self, tool: ITool, objUiState: Any) -> None: ...

class ManualScaleYDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, control: ICompoundsAtAGlance) -> None: ...

class OrganizeType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Compounds: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType
    ) = ...  # static # readonly
    Samples: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType
    ) = ...  # static # readonly

class Overlay(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    CompoundGroups: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    Compounds: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    ISTD: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    MatrixSpike: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    Qualifiers: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    SampleGroups: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    Samples: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly
    SeparateQualifiers: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    ) = ...  # static # readonly

class PaneDataExtractor:  # Class
    def __init__(self) -> None: ...

    ExtractorCount: int  # readonly
    RangeX: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange]
    RangeY: Optional[Agilent.MassSpectrometry.GUI.Plot.PlotRange]
    Title: str

    def GetExtractor(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase
    ): ...
    def AddExtractor(
        self,
        extractor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase,
    ) -> None: ...

class Peak:  # Class
    @overload
    def __init__(self, peak: QuantitationDataSet.PeakRow, centerY: float) -> None: ...
    @overload
    def __init__(
        self, peak: QuantitationDataSet.PeakQualifierRow, centerY: float
    ) -> None: ...

    Area: Optional[float]  # readonly
    Base1End: Optional[float]  # readonly
    Base1Start: Optional[float]  # readonly
    Base2End: Optional[float]  # readonly
    Base2Start: Optional[float]  # readonly
    BaselineEndX: Optional[float]  # readonly
    BaselineEndY: Optional[float]  # readonly
    BaselineOffset: Optional[float]  # readonly
    BaselineStandardDeviation: Optional[float]  # readonly
    BaselineStartX: Optional[float]  # readonly
    BaselineStartY: Optional[float]  # readonly
    Center: float  # readonly
    CenterY: float  # readonly
    CompoundName: str  # readonly
    Height: Optional[float]  # readonly
    IsManualIntegrated: bool  # readonly
    IsPrimary: bool  # readonly
    PeakStatus: Agilent.MassSpectrometry.DataAnalysis.PeakStatus  # readonly
    RowId: RowIdBase  # readonly

class PeakAnnotationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Area: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    CalculatedConcentration: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    DeltaRetentionTime: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    FinalConcentration: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    Height: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    QValueComputed: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    QualifierResponseRatio: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    RetentionTime: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly
    SignalToNoiseRatio: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ) = ...  # static # readonly

class PlotData(
    Agilent.MassSpectrometry.GUI.Plot.IMarkerData,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PlotDataBase,
    Agilent.MassSpectrometry.GUI.Plot.IPlotData,
    Agilent.MassSpectrometry.GUI.Plot.IPeakData,
):  # Class
    def __init__(
        self,
        control: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagViewControl,
        extractor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PaneDataExtractor,
    ) -> None: ...

    Initialized: bool  # readonly
    PaneDataExtractor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PaneDataExtractor
    )  # readonly

    def Initialize(self, pane: Agilent.MassSpectrometry.GUI.Plot.Pane) -> None: ...

class PlotDataBase:  # Class
    ...

class PresetLayout(System.Configuration.ConfigurationElement):  # Class
    def __init__(self) -> None: ...

    Baselines: Optional[bool]
    CompoundFilter: str
    CompoundOrder: str
    DimensionX: Optional[int]
    DimensionY: Optional[int]
    FillPeaks: Optional[bool]
    FitToHighestLevel: bool
    FitToLowestLevel: bool
    FitToPeak: bool
    FitToPeakHeight: bool
    LinkAllXAxes: bool
    LinkAllYAxes: bool
    LinkXAxes: bool
    LinkYAxes: bool
    MenuText: str
    Name: str
    Normalize: Optional[bool]
    OrganizeRows: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType
    )
    Outliers: str
    Overlay: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    )
    PeakAnnotations: str
    ReviewMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    )
    SampleFilter: str
    SampleOrder: str
    Separator: bool
    ShowPeakAnnotationNames: Optional[bool]
    ShowPeakAnnotationUnits: Optional[bool]
    UncertaintyBand: Optional[bool]
    WrapRows: bool

class PresetLayoutCollection(
    Iterable[Any], System.Configuration.ConfigurationElementCollection, Sequence[Any]
):  # Class
    def __init__(self) -> None: ...
    def __getitem__(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PresetLayout
    ): ...

class PropPage(
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UserControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    IPropertyPage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.IWin32Window,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
):  # Class
    def __init__(
        self,
        control: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagViewControl,
    ) -> None: ...

class ReviewCompoundGroupItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewItem,
    IReviewItem,
):  # Class
    def __init__(self, dataset: BatchDataSet, groupName: str) -> None: ...
    def MatchCompound(self, rowId: TargetCompoundRowId) -> bool: ...
    def MatchSample(self, rowId: SampleRowId) -> bool: ...

class ReviewCompoundItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewItem,
    IReviewItem,
):  # Class
    def __init__(self, dataSet: BatchDataSet, rowId: TargetCompoundRowId) -> None: ...
    def MatchCompound(self, rowId: TargetCompoundRowId) -> bool: ...
    def MatchSample(self, rowId: SampleRowId) -> bool: ...

class ReviewItem(IReviewItem):  # Class
    def __init__(self) -> None: ...

    DisplayText: str

    def MatchCompound(self, rowId: TargetCompoundRowId) -> bool: ...
    def MatchSample(self, rowId: SampleRowId) -> bool: ...

class ReviewMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CompoundByCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    ) = ...  # static # readonly
    CompoundGroupByCompoundGroup: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    ) = ...  # static # readonly
    SampleBySample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    ) = ...  # static # readonly

class ReviewSampleItem(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewItem,
    IReviewItem,
):  # Class
    def __init__(self, dataSet: BatchDataSet, rowId: SampleRowId) -> None: ...
    def MatchCompound(self, rowId: TargetCompoundRowId) -> bool: ...
    def MatchSample(self, rowId: SampleRowId) -> bool: ...

class SeriesCompoundMath(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
):  # Class
    def __init__(
        self,
        extractor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorCompoundMath,
    ) -> None: ...

    MaxY: float  # readonly
    PlotMode: Agilent.MassSpectrometry.GUI.Plot.PlotModes  # readonly
    PointCount: int  # readonly

    def GetPoint(self, index: int, x: float, y: float) -> None: ...

class SeriesDataBase:  # Class
    Annotation: str
    Color: System.Drawing.Color
    Display: bool
    Extractor: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase
    )  # readonly
    ManualIntegrated: bool
    MaxY: float  # readonly
    Outlier: bool
    OutlierMessage: str
    PeakCount: int  # readonly
    PlotMode: Agilent.MassSpectrometry.GUI.Plot.PlotModes  # readonly
    PointCount: int  # readonly
    Style: System.Drawing.Drawing2D.DashStyle
    Width: int

    def GetYFromX(self, x: float) -> Optional[float]: ...
    def AddPeak(
        self,
        peak: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Peak,
    ) -> None: ...
    def GetPeak(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Peak: ...
    def GetPoint(self, index: int, x: float, y: float) -> None: ...
    def FindIndex(self, x: float) -> int: ...
    def ClearPeaks(self) -> None: ...

class SeriesExceptionData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
):  # Class
    def __init__(
        self,
        extractor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase,
        exception: System.Exception,
    ) -> None: ...

    Exception: System.Exception  # readonly
    MaxY: float  # readonly
    PlotMode: Agilent.MassSpectrometry.GUI.Plot.PlotModes  # readonly
    PointCount: int  # readonly

    def GetPoint(self, index: int, x: float, y: float) -> None: ...

class SeriesFXData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.SeriesDataBase
):  # Class
    def __init__(
        self,
        extractor: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ExtractorBase,
        data: Agilent.MassSpectrometry.DataAnalysis.IFXData,
    ) -> None: ...

    MaxY: float  # readonly
    PlotMode: Agilent.MassSpectrometry.GUI.Plot.PlotModes  # readonly
    PointCount: int  # readonly

    def GetPoint(self, index: int, x: float, y: float) -> None: ...

class SetupGraphicsContext(System.IDisposable):  # Class
    def __init__(
        self, dataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator
    ) -> None: ...

    ColumnCount: int  # readonly
    CompoundCount: int  # readonly
    Compounds: Iterable[TargetCompoundRowId]  # readonly
    CurrentReviewItemIndex: Optional[int]  # readonly
    DataNavigator: Agilent.MassHunter.Quantitative.UIModel.IDataNavigator  # readonly
    FillPeaks: bool
    Layout: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.CagLayout
    )  # readonly
    Normalize: bool
    Organize: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.OrganizeType
    )
    Outliers: Iterable[OutlierColumns]  # readonly
    Overlay: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.Overlay
    )
    PeakAnnotations: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PeakAnnotationType
    ]
    PresentationState: (
        Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    )  # readonly
    QualifierInfoLabelType: QualifierInfoLabelType
    RecognitionWindowColor: System.Drawing.Color
    RecognitionWindowDashStyle: System.Drawing.Drawing2D.DashStyle
    ReferenceRTColor: System.Drawing.Color
    ReferenceRTDashStyle: System.Drawing.Drawing2D.DashStyle
    ReviewItemCount: int  # readonly
    ReviewMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewMode
    )
    RowCount: int  # readonly
    SampleCount: int  # readonly
    Samples: Iterable[SampleRowId]  # readonly
    ShowBaselines: bool
    ShowManualIntegrationHandles: bool
    ShowPeakAnnotationNames: bool
    ShowPeakAnnotationUnits: bool
    ShowRecognitionWindow: bool
    ShowReferenceRT: bool
    ShowUncertainBands: bool
    WrapMode: bool

    def AddAllSamplesAllCompounds(self) -> None: ...
    def AddCompounds(self, compounds: Iterable[TargetCompoundRowId]) -> None: ...
    def UpdateOutliers(self) -> None: ...
    def GetReviewItems(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.ReviewItem
    ]: ...
    def ClearCompounds(self) -> None: ...
    def SetOutliers(self, columns: Iterable[OutlierColumns]) -> None: ...
    def GetAvailableOutliers(self) -> Iterable[OutlierColumns]: ...
    def InitConfiguration(self) -> None: ...
    def MatchOutlier(
        self,
        relation: str,
        row: System.Data.DataRow,
        builder: System.Text.StringBuilder,
    ) -> bool: ...
    def ClearSamples(self) -> None: ...
    def Dispose(self) -> None: ...
    def AddSamples(self, samples: Iterable[SampleRowId]) -> None: ...
    def GetExtractor(
        self, row: int, col: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CompoundsAtAGlance.PaneDataExtractor
    ): ...
    def SetupExtractors(self) -> None: ...

class ToolHandlerChromatograms(IToolHandler):  # Class
    def __init__(self) -> None: ...

class ToolHandlerMain(IToolHandler, IToolBeforeDropdownHandler):  # Class
    def __init__(self) -> None: ...

    Ext_CagLayout: str = ...  # static # readonly

class ToolbarsManager(
    System.ComponentModel.ISupportInitialize,
    System.IDisposable,
    ToolbarsManagerBase,
    System.Windows.Forms.IMessageFilter,
    IToolbarsManager,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, tool: str, module: str, setState: str, execute: str
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodDiff.Properties

class Resources:  # Class
    AppName: str  # static # readonly
    Compare: System.Drawing.Bitmap  # static # readonly
    CompoundName: str  # static # readonly
    CompoundNameLevelName: str  # static # readonly
    CompoundNameTransition: str  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    Err_MethodNotExist: str  # static # readonly
    Label_Column: str  # static # readonly
    Label_Date: str  # static # readonly
    Label_Description: str  # static # readonly
    Label_Details: str  # static # readonly
    Label_DisplayName: str  # static # readonly
    Label_File1Exists: str  # static # readonly
    Label_File2Exists: str  # static # readonly
    Label_Identical: str  # static # readonly
    Label_Modified: str  # static # readonly
    Label_Name: str  # static # readonly
    Label_Reason: str  # static # readonly
    Label_Revision: str  # static # readonly
    Label_Table: str  # static # readonly
    Label_Type: str  # static # readonly
    Label_User: str  # static # readonly
    Label_Value1: str  # static # readonly
    Label_Value2: str  # static # readonly
    MethodItemType_General: str  # static # readonly
    MethodItemType_Quant: str  # static # readonly
    MethodItemType_QuantReport: str  # static # readonly
    MethodItemType_Unknowns: str  # static # readonly
    MethodItemType_UnknownsReport: str  # static # readonly
    Msg_BothMethodsNotExist: str  # static # readonly
    Msg_CannotCompareFolderAndFile: str  # static # readonly
    Msg_ComplianceNotSupported: str  # static # readonly
    Msg_Method1NotExist: str  # static # readonly
    Msg_Method2NotExist: str  # static # readonly
    Msg_MethodsIdentical: str  # static # readonly
    Progress_RetrievingHistory: str  # static # readonly
    Progress_Revision: str  # static # readonly
    Report_Column: str  # static # readonly
    Report_ComplianceName: str  # static # readonly
    Report_Date: str  # static # readonly
    Report_Description: str  # static # readonly
    Report_FileCreated: str  # static # readonly
    Report_FileNotExist: str  # static # readonly
    Report_FileRemoved: str  # static # readonly
    Report_Generated: str  # static # readonly
    Report_Identical: str  # static # readonly
    Report_MethodPath: str  # static # readonly
    Report_Modified: str  # static # readonly
    Report_PageNumber: str  # static # readonly
    Report_Reason: str  # static # readonly
    Report_ReportDate: str  # static # readonly
    Report_Revision: str  # static # readonly
    Report_Revisions: str  # static # readonly
    Report_Server: str  # static # readonly
    Report_Summary: str  # static # readonly
    Report_Table: str  # static # readonly
    Report_Title: str  # static # readonly
    Report_Type: str  # static # readonly
    Report_User: str  # static # readonly
    Report_Value1: str  # static # readonly
    Report_Value2: str  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    SampleName: str  # static # readonly
    Usage: str  # static # readonly
    app: System.Drawing.Icon  # static # readonly
    history: System.Drawing.Icon  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ComponentHitID
from .Model import IUIContext
from .ScriptIF import IUIState

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools

class AnalysisDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...
    def DeconvoluteSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
        reanalyze: bool,
    ) -> None: ...
    def AnalyzeAll(self, reanalyze: bool) -> None: ...
    def TargetMatchSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
        reanalyze: bool,
    ) -> None: ...
    def AnalyzeSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
        reanalyze: bool,
    ) -> None: ...
    def DeconvoluteAll(self, reanalyze: bool) -> None: ...
    def IdentifySamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
        reanalyze: bool,
    ) -> None: ...
    def TargetMatchAll(self, reanalyze: bool) -> None: ...
    def IdentifyAll(self, reanalyze: bool) -> None: ...
    def BlankSubtractSamples(
        self,
        samples: List[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.SampleRowIDParameter
        ],
        reanalyze: bool,
    ) -> None: ...
    def Cancel(self) -> None: ...
    def BlankSubtractAll(self, reanalyze: bool) -> None: ...

class AnalysisProgressDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    Relations: System.Data.DataRelationCollection  # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleDataTable
    )  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class SampleDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ],
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        BatchIDColumn: System.Data.DataColumn  # readonly
        BlankSubtractionColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        DeconvolutionColumn: System.Data.DataColumn  # readonly
        IdentificationColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ): ...
        SampleIDColumn: System.Data.DataColumn  # readonly
        SampleNameColumn: System.Data.DataColumn  # readonly
        TargetMatchColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        @overload
        def AddSampleRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow,
        ) -> None: ...
        @overload
        def AddSampleRow(
            self,
            BatchID: int,
            SampleID: int,
            SampleName: str,
            Deconvolution: float,
            Identification: float,
            BlankSubtraction: float,
            TargetMatch: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ): ...
        def FindByBatchIDSampleID(
            self, BatchID: int, SampleID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def NewSampleRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        ): ...
        def RemoveSampleRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow,
        ) -> None: ...

        SampleRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEventHandler
        )  # Event
        SampleRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEventHandler
        )  # Event

    class SampleRow(System.Data.DataRow):  # Class
        BatchID: int
        BlankSubtraction: float
        Deconvolution: float
        Identification: float
        SampleID: int
        SampleName: str
        TargetMatch: float

        def IsTargetMatchNull(self) -> bool: ...
        def IsIdentificationNull(self) -> bool: ...
        def SetIdentificationNull(self) -> None: ...
        def IsDeconvolutionNull(self) -> bool: ...
        def SetBlankSubtractionNull(self) -> None: ...
        def IsBlankSubtractionNull(self) -> bool: ...
        def IsSampleNameNull(self) -> bool: ...
        def SetDeconvolutionNull(self) -> None: ...
        def SetSampleNameNull(self) -> None: ...
        def SetTargetMatchNull(self) -> None: ...

    class SampleRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRow
        )  # readonly

    class SampleRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.AnalysisProgressDataSet.SampleRowChangeEvent,
        ) -> None: ...

class CompressResultsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

class ExportComponentTableDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    DestinationType: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.ExportDestinationType
    )
    ExportAllComponents: bool  # readonly
    NonHitAutoCompoundNames: bool  # readonly
    NonHitCompoundNameAddIndex: bool  # readonly
    NonHitCompoundNamePrefix: str  # readonly

class ExportDestinationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Csv: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.ExportDestinationType
    ) = ...  # static # readonly
    Library: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.ExportDestinationType
    ) = ...  # static # readonly
    QuantMethod: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Tools.ExportDestinationType
    ) = ...  # static # readonly

class ExportQuantMethodDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    DestinationPath: str
    IonMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodFromLibraryIonMode
    NumQualifiers: int

class GenerateReport(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand
):  # Class
    def __init__(self) -> None: ...

    ActionString: str  # readonly
    Method: str
    Name: str  # readonly
    OutputPath: str

class LoadMethodDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

class ReportDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiState: IUIState) -> None: ...

    AllSamples: bool
    GenerateNow: bool
    Method: str
    OpenReportFolder: bool
    OutputPath: str
    StartQueueViewer: bool

    @staticmethod
    def GenerateDefaultOutputDirectory(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        batchFolder: str,
        analysisFile: str,
    ) -> str: ...

class TargetCompoundsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self, uiContext: IUIContext) -> None: ...

    IsEditable: bool  # readonly

    @staticmethod
    def FindTargetCompoundByHit(
        dataFile: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataFile.DataFileBase,
        hit: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.HitRow,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetCompoundRow
    ): ...
    def InitBySample(self, batchID: int, sampleID: int) -> None: ...
    def AddISTDByHits(self, ids: List[ComponentHitID]) -> None: ...
    def AddISTDByHit(self, chid: ComponentHitID) -> None: ...

class ToolHandlerAnalyze(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CompressResults(uiState: IUIState) -> None: ...

class ToolHandlerChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerComponent(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerEdit(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerEicPeaks(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerExactMass(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        objState: Any,
    ) -> None: ...
    def SetState(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        objState: Any,
    ) -> None: ...

class ToolHandlerFile(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IDropDownHandler,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def SaveAnalysis(uiState: IUIState) -> bool: ...
    @staticmethod
    def PushRecentAnaysisFile(path: str) -> None: ...
    @staticmethod
    def SetMaxRecentAnalysisFiles(max: int) -> None: ...
    @staticmethod
    def SaveAnalysisAs(
        uiState: IUIState, batchFolder: str, analysisFile: str
    ) -> bool: ...
    @staticmethod
    def RemoveRecentAnalysisFile(path: str) -> None: ...
    @staticmethod
    def GetRecentAnalysisFiles() -> List[str]: ...
    @staticmethod
    def OpenAnalysis(
        uiState: IUIState,
        batchFolder: str,
        fileName: str,
        revisionNumber: str,
        readOnly: bool,
    ) -> bool: ...
    @overload
    @staticmethod
    def NewAnalysis(uiState: IUIState) -> None: ...
    @overload
    @staticmethod
    def NewAnalysis(
        uiState: IUIState, batchFolder: str, fileName: str, auditTrail: bool
    ) -> bool: ...
    @staticmethod
    def OpenAnalysisFromPath(
        state: IUIState, file: str, readOnly: bool
    ) -> System.Exception: ...
    @staticmethod
    def CloseAnalysis(uiState: IUIState) -> bool: ...

class ToolHandlerHelp(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerIonPeaks(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerMethod(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerReport(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerSample(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerScript(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        objUiState: Any,
    ) -> None: ...
    def SetState(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.ITool,
        uiState: Any,
    ) -> None: ...

class ToolHandlerSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolHandlerTools(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IDropDownHandler,
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def RunScript(uiState: IUIState, scriptFiles: List[str]) -> None: ...

class ToolHandlerView(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolHandler
):  # Class
    def __init__(self) -> None: ...

class ToolsUtils:  # Class
    @overload
    @staticmethod
    def ExecuteCommand(
        parent: System.Windows.Forms.IWin32Window,
        cmd: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandBase,
    ) -> bool: ...
    @overload
    @staticmethod
    def ExecuteCommand(
        parent: System.Windows.Forms.IWin32Window,
        cmd: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandBase,
        ret: Any,
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.AnalysisForm.Properties

class Resources:  # Class
    BatchState_Modified: str  # static # readonly
    BatchState_Processed: str  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    ERROR: System.Drawing.Bitmap  # static # readonly
    ErrMsg_CannotInitializeModule: str  # static # readonly
    ErrMsg_CannotRecognizeLayoutFile: str  # static # readonly
    ErrMsg_LayoutFileCollapsedUseDefaultLayout: str  # static # readonly
    ErrMsg_LayoutFileIsBatchMode: str  # static # readonly
    ErrMsg_LayoutFileIsMethodMode: str  # static # readonly
    ErrMsg_UnableToApplyPreviousLayout: str  # static # readonly
    FormTitle_Method: str  # static # readonly
    FormTitle_NewMethod: str  # static # readonly
    FormTitle_ReadOnly: str  # static # readonly
    Msg_MethodValidationMessages: str  # static # readonly
    Msg_NoMethodValidationMessage: str  # static # readonly
    PaneCaption_BatchTable: str  # static # readonly
    PaneCaption_CalibrationCurve: str  # static # readonly
    PaneCaption_CompoundInformation: str  # static # readonly
    PaneCaption_MethodErrorList: str  # static # readonly
    PaneCaption_MethodTable: str  # static # readonly
    PaneCaption_MethodTasks: str  # static # readonly
    PaneCaption_MetricsPlot: str  # static # readonly
    PaneCaption_SampleInformation: str  # static # readonly
    PaneCaption_Script: str  # static # readonly
    QuantitativeAnalysisDeskTop: System.Drawing.Icon  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    StatusPaenl_Tooltip_Connection: str  # static # readonly
    StatusPanel_CheckingConnection: str  # static # readonly
    StatusPanel_ConnectedTo: str  # static # readonly
    StatusPanel_ConnectionError: str  # static # readonly
    StatusPanel_Tooltip_BatchState: str  # static # readonly
    StatusPanel_Tooltip_CompoundName: str  # static # readonly
    StatusPanel_Tooltip_ConnectionError: str  # static # readonly
    StatusPanel_Tooltip_Coordinates: str  # static # readonly
    StatusPanel_Tooltip_SampleName: str  # static # readonly
    StatusPanel_Tooltip_Table: str  # static # readonly
    StatusPanel_Tooltip_User: str  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
TData = TypeVar("TData")
from .CoreTypes import IExtractionParameters

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.CoreType

class ExtractedSignalDataContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreType.IExtractedSignalDataContainer[TData],
    Generic[TData],
    Agilent.OpenLab.Framework.DataAccess.CoreType.SignalDataContainer[TData],
    Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalDataContainer[TData],
):  # Class
    def __init__(
        self,
        signalData: TData,
        signalMetaData: Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalMetaData,
        extractionParameters: IExtractionParameters,
    ) -> None: ...

    ExtractionParameters: IExtractionParameters  # readonly

class IExtractedSignalDataContainer(
    Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalDataContainer[TData]
):  # Interface
    ExtractionParameters: IExtractionParameters  # readonly

class ISignalDataContainer(object):  # Interface
    SignalData: TData  # readonly
    SignalMetaData: (
        Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalMetaData
    )  # readonly

class ISignalMetaData(object):  # Interface
    Description: str  # readonly
    Name: str  # readonly
    TraceId: str  # readonly

class SignalDataContainer(
    Generic[T], Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalDataContainer[T]
):  # Class
    def __init__(
        self,
        signalData: T,
        signalMetaData: Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalMetaData,
    ) -> None: ...

    SignalData: T  # readonly
    SignalMetaData: (
        Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalMetaData
    )  # readonly

class SignalMetaData(
    Agilent.OpenLab.Framework.DataAccess.CoreType.ISignalMetaData
):  # Class
    def __init__(self, name: str, description: str, traceId: str) -> None: ...

    Description: str  # readonly
    Name: str  # readonly
    TraceId: str  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.QuantWPF.AppMenu

class ExportGraphicsView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ExportGraphicsViewModel:  # Class
    def __init__(self) -> None: ...

class ExportTableFileTypeItem:  # Class
    def __init__(self) -> None: ...

    Description: str
    Extension: str
    Image: System.Windows.Media.Imaging.BitmapSource  # readonly
    Label: str  # readonly
    Name: str

class ExportTableView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ExportTableViewModel:  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.QuantWPF.AppMenu.ExportViewModel
    ) -> None: ...

    ExportCommand: System.Windows.Input.ICommand  # readonly
    ExportEntireTable: bool
    ExportSelectedRows: bool
    FileTypes: List[
        Agilent.MassHunter.Quantitative.QuantWPF.AppMenu.ExportTableFileTypeItem
    ]  # readonly
    OpenExportedFile: bool
    SelectedFileType: (
        Agilent.MassHunter.Quantitative.QuantWPF.AppMenu.ExportTableFileTypeItem
    )

class ExportView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ExportViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...

    CurrentViewModelProperty: System.Windows.DependencyProperty  # static # readonly
    ItemsProperty: System.Windows.DependencyProperty  # static # readonly

    CurrentViewModel: Any
    Items: List[Agilent.MassHunter.Quantitative.QuantWPF.AppMenu.ExportViewModel.Item]
    SelectedPaneID: str

    def GetView(
        self,
    ) -> Agilent.MassHunter.Quantitative.QuantWPF.AppMenu.ExportView: ...
    def InitItems(self) -> None: ...

    # Nested Types

    class Item:  # Class
        def __init__(self, paneId: str, label: str) -> None: ...

        Label: str
        PaneID: str

class OpenRecentViewItemContextMenu(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(
        self,
        viewModel: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModel,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Configuration

class UserConfiguration:  # Class
    def __init__(self) -> None: ...

    s_instance: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Configuration.UserConfiguration
    )  # static

    Instance: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Configuration.UserConfiguration
    )  # static # readonly
    LastInstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: IWshRuntimeLibrary

class IWshShell(object):  # Interface
    ...

class IWshShell2(IWshRuntimeLibrary.IWshShell):  # Interface
    ...

class IWshShell3(
    IWshRuntimeLibrary.IWshShell2, IWshRuntimeLibrary.IWshShell
):  # Interface
    def CreateShortcut(self, PathLink: str) -> Any: ...

class IWshShortcut(object):  # Interface
    Arguments: str
    TargetPath: str

    def Save(self) -> None: ...

class WshShell(
    IWshRuntimeLibrary.IWshShell3,
    IWshRuntimeLibrary.IWshShell2,
    IWshRuntimeLibrary.IWshShell,
):  # Interface
    ...

class WshShortcut(IWshRuntimeLibrary.IWshShortcut):  # Interface
    ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import ComponentFilter, ComponentHitID
from .Model import IMainWindow
from .ScriptIF import (
    ChromatogramViewMode,
    IAddIn,
    IAddInManager,
    IAnalysisMessageTable,
    IChromatogramPane,
    ICompliance,
    IComponentTable,
    IEICPane,
    IExactMassTable,
    IGridPane,
    IIonPeaksPane,
    IMainForm,
    IPane,
    IPlotPane,
    IQueryAnalysis,
    ISampleTable,
    IScriptEngine,
    IScriptInterface,
    IScriptPane,
    IScriptScope,
    ISpectrumPane,
    IStructurePane,
    IUADataAccess,
    IUIState,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls

class AddIn(System.MarshalByRefObject, IAddIn):  # Class
    DisplayName: str  # readonly
    Enabled: bool
    Name: str  # readonly
    PathName: str  # readonly

class AddInManager(
    System.MarshalByRefObject, System.IDisposable, IAddInManager
):  # Class
    Count: int  # readonly
    def __getitem__(self, id: str) -> IAddIn: ...
    def Dispose(self) -> None: ...
    def GetIDs(self) -> List[str]: ...

class AnalysisMessageTable(
    IPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.GridPaneBase,
    System.IDisposable,
    IAnalysisMessageTable,
    System.Windows.Forms.IWin32Window,
):  # Class
    ...

class ChromatogramPane(
    IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PlotPaneBase,
    System.IDisposable,
    IPane,
    IChromatogramPane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanAutoScaleXY: bool  # readonly
    CanCopy: bool  # readonly
    ChromatogramViewMode: ChromatogramViewMode
    ShowComponents: bool
    ShowEics: bool
    ShowTic: bool

    def Copy(self) -> None: ...
    def AutoScaleXY(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...

class Compliance(System.MarshalByRefObject, ICompliance):  # Class
    ConnectionTicket: str  # readonly
    IsActive: bool  # readonly
    IsLocal: bool  # readonly
    Name: str  # readonly
    User: str  # readonly

class ComponentTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.GridPaneBase,
    IGridPane,
    System.IDisposable,
    IComponentTable,
    IPane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanCopy: bool  # readonly
    CanDeleteComponentsHits: bool  # readonly
    CanExport: bool  # readonly
    CanFormatColumn: bool  # readonly
    CanSetBestHits: bool  # readonly

    def SetColumnVisible(self, columnName: str, visible: bool) -> None: ...
    def ExportToText(
        self,
        allComponents: bool,
        writer: System.IO.TextWriter,
        delimiter: str,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def FormatColumn(self) -> None: ...
    def SetBestHits(self) -> None: ...
    def Copy(self) -> None: ...
    def IsColumnVisible(self, columnName: str) -> bool: ...
    def ExportToLibrary(
        self,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
    ) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def DeleteComponentsHits(self) -> None: ...
    def RestoreComponentsHits(self) -> None: ...
    def ExportToQuantMethod(
        self,
        destination: str,
        allComponents: bool,
        autoCompoundNames: bool,
        nonHitPrefix: str,
        nonHitAddIndex: bool,
        ionMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.MethodFromLibraryIonMode,
        numQualifiers: int,
    ) -> None: ...

class ExactMassTable(
    IPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.GridPaneBase,
    System.IDisposable,
    IExactMassTable,
    IGridPane,
):  # Class
    CanCopy: bool  # readonly
    CanFormatColumn: bool  # readonly

    def FormatColumn(self) -> None: ...
    def Copy(self) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def ShowAlternativeExactMassDialog(self) -> None: ...
    def CanShowAlternativeExactMassDialog(self) -> bool: ...

class GridPaneBase(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PaneBase,
    IPane,
    System.IDisposable,
):  # Class
    CanPrint: bool  # readonly

    def PageSetup(self) -> None: ...
    def PrintDialog(self) -> None: ...
    def PrintPreview(self) -> None: ...

class IonPeaksPane(
    IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PlotPaneBase,
    System.IDisposable,
    IIonPeaksPane,
    IPane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanAutoScaleXY: bool  # readonly
    CanCopy: bool  # readonly
    ShowComponent: bool
    ShowTIC: bool

    def Copy(self) -> None: ...
    def AutoScaleXY(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...

class MainForm(
    System.MarshalByRefObject, IMainForm, System.Windows.Forms.IWin32Window
):  # Class
    ActivePane: IPane  # readonly
    AnalysisMessageTable: IAnalysisMessageTable  # readonly
    ChromatogramPane: IChromatogramPane  # readonly
    ComponentTable: IComponentTable  # readonly
    EICPane: IEICPane  # readonly
    ExactMassTable: IExactMassTable  # readonly
    IonPeaksPane: IIonPeaksPane  # readonly
    SampleTable: ISampleTable  # readonly
    ScriptPane: IScriptPane  # readonly
    SpectrumPane: ISpectrumPane  # readonly
    StructurePane: IStructurePane  # readonly
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    _Form: IMainWindow  # readonly

    def Layout(self, layout: int) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def Close(self, forceClose: bool) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def ShowQuery(self, queryFile: str) -> None: ...

class PaneBase(IPane, System.MarshalByRefObject, System.IDisposable):  # Class
    CanCopy: bool  # readonly
    CanPrint: bool  # readonly
    Visible: bool

    def GetActiveObject(self) -> T: ...
    def Copy(self) -> None: ...
    def PrintDialog(self) -> None: ...
    def PageSetup(self) -> None: ...
    def PrintPreview(self) -> None: ...
    def Dispose(self) -> None: ...

class PlotPaneBase(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PaneBase,
    IPane,
    System.IDisposable,
):  # Class
    CanNextZoom: bool  # readonly
    CanPrevZoom: bool  # readonly
    CanPrint: bool  # readonly

    def PrevZoom(self) -> None: ...
    def PrintDialog(self) -> None: ...
    def PageSetup(self) -> None: ...
    def PrintPreview(self) -> None: ...
    def NextZoom(self) -> None: ...

class QueryAnalysis(
    System.MarshalByRefObject, IQueryAnalysis, System.IDisposable
):  # Class
    def QuerySamples(
        self, batchID: Optional[int]
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.SampleDataTable
    ): ...
    def Dispose(self) -> None: ...
    def QueryBatches(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.BatchDataTable
    ): ...

class SampleTable(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.GridPaneBase,
    ISampleTable,
    IGridPane,
    System.IDisposable,
    IPane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanCopy: bool  # readonly
    CanFormatColumn: bool  # readonly

    def Copy(self) -> None: ...
    def ShowColumnsDialog(self) -> None: ...
    def FormatColumn(self) -> None: ...

class ScriptEngine(
    IScriptEngine, System.MarshalByRefObject, System.IDisposable
):  # Class
    CurrentScope: IScriptScope  # readonly
    DebugMode: bool  # readonly
    Engine: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptEngine
    )  # readonly
    Globals: IScriptScope  # readonly

    def CreateScope(self) -> IScriptScope: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: IScriptScope,
    ) -> Any: ...
    @staticmethod
    def SetDebugEngine(
        engine: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IronEngine,
        initEngine: System.Action[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IronEngine,
            Any,
        ],
    ) -> None: ...
    def Dispose(self) -> None: ...
    def ExecuteFile(self, file: str, scope: IScriptScope) -> Any: ...

class ScriptInterface(
    IScriptInterface, System.MarshalByRefObject, System.IDisposable
):  # Class
    Compliance: ICompliance  # readonly
    ScriptEngine: IScriptEngine  # readonly
    UADataAccess: IUADataAccess  # readonly
    UIState: IUIState  # readonly
    _ScriptInterface: IScriptInterface  # readonly

    def Dispose(self) -> None: ...
    def _GetPrivateProfileString(
        self, section: str, key: str, defaultValue: str, fileName: str
    ) -> str: ...
    def _WritePrivateProfileString(
        self, section: str, key: str, value_: str, fileName: str
    ) -> int: ...

class ScriptPane(
    System.IDisposable,
    IPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PaneBase,
    IScriptPane,
):  # Class
    CanCopy: bool  # readonly

    def Copy(self) -> None: ...
    def Run(self) -> None: ...
    def Clear(self) -> None: ...

class SpectrumPane(
    IPlotPane,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PlotPaneBase,
    System.IDisposable,
    ISpectrumPane,
    IPane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanAutoScaleXY: bool  # readonly
    CanCopy: bool  # readonly
    HeadToTail: bool
    ShowExtractedSpectrum: bool

    def Copy(self) -> None: ...
    def GetActiveObject(self) -> T: ...
    def AutoScaleXY(self) -> None: ...
    def ShowPropertiesDialog(self) -> None: ...

class StructurePane(
    IPane,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.PaneBase,
    IStructurePane,
    System.Windows.Forms.IWin32Window,
):  # Class
    CanCopy: bool  # readonly
    CanPrint: bool  # readonly

    def PageSetup(self) -> None: ...
    def Copy(self) -> None: ...
    def PrintDialog(self) -> None: ...
    def PrintPreview(self) -> None: ...

class UADataAccess(System.MarshalByRefObject, IUADataAccess):  # Class
    def GetBatches(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.BatchDataTable
    ): ...
    def GetLibrarySearchMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.LibrarySearchMethodDataTable
    ): ...
    def GetHits(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.HitDataTable
    ): ...
    def GetPeakQualifier(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.PeakQualifierDataTable
    ): ...
    def GetIonPeak(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.IonPeakDataTable
    ): ...
    def Base64ToDoubleArray(self, base64: str) -> List[float]: ...
    def GetTargetQualifier(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetQualifierDataTable
    ): ...
    def GetPeak(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.PeakDataTable
    ): ...
    def GetTargetMatchMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetMatchMethodDataTable
    ): ...
    def GetAnalysis(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.AnalysisDataTable
    ): ...
    def GetAuxiliaryMethod(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.AuxiliaryMethodDataTable
    ): ...
    def GetComponents(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.ComponentDataTable
    ): ...
    def GetDeconvolutionMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.DeconvolutionMethodDataTable
    ): ...
    def GetIdentificationMethods(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.IdentificationMethodDataTable
    ): ...
    def GetSamples(
        self, batchID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.SampleDataTable
    ): ...
    def GetTargetCompounds(
        self, batchID: int, sampleID: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UnknownsAnalysisDataSet.TargetCompoundDataTable
    ): ...

class UIState(System.MarshalByRefObject, IUIState, System.IDisposable):  # Class
    def __init__(self, mainForm: IMainWindow) -> None: ...

    ActiveForm: System.Windows.Forms.IWin32Window  # readonly
    ActivePane: IPane  # readonly
    AddInManager: IAddInManager  # readonly
    AnalysisFileName: str  # readonly
    BatchFolder: str  # readonly
    BestHitsOnly: bool
    BestPrimaryHitsOnly: bool
    BlankComponent: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.ComponentRowID
    )
    BlankSubtractedHits: bool
    CanRedo: bool  # readonly
    CanUndo: bool  # readonly
    ComponentFilter: ComponentFilter
    Constants: Dict[str, str]  # readonly
    ExitCode: int
    FilePath: str  # readonly
    HasAnalysis: bool  # readonly
    IsAuditTrailing: bool  # readonly
    IsDirty: bool  # readonly
    MainForm: IMainForm  # readonly
    PrimaryHitsOnly: bool
    QueryAnalysis: IQueryAnalysis  # readonly
    SampleCount: int  # readonly
    ScriptEngine: IScriptEngine  # readonly
    SelectedComponentHitCount: int  # readonly
    SelectedSampleCount: int  # readonly
    SelectedSamples: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
    ]  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    UADataAccess: IUADataAccess  # readonly
    _ExitCode: int  # static

    def IsSampleSelected(self, batchId: int, sampleId: int) -> bool: ...
    def GetSelectedComponentHits(self) -> Iterable[ComponentHitID]: ...
    def SelectSamples(
        self,
        samples: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.SampleRowID
        ],
    ) -> None: ...
    def ShowAuditTrailWindow(self) -> None: ...
    def SelectComponentHits(
        self, chids: Iterable[ComponentHitID], clear: bool
    ) -> None: ...
    def Dispose(self) -> None: ...
    @overload
    def RunScript(self, file: str) -> Any: ...
    @overload
    def RunScript(self, stream: System.IO.Stream) -> Any: ...
    def ShowMessage(
        self,
        message: str,
        caption: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import CDBDataSet

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Compounds.CDBDataSetTableAdapters

class CompoundsTableAdapter(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.ComponentModel.Component,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ClearBeforeFill: bool

    @overload
    def Update(self, dataTable: CDBDataSet.CompoundsDataTable) -> int: ...
    @overload
    def Update(self, dataSet: CDBDataSet) -> int: ...
    @overload
    def Update(self, dataRow: System.Data.DataRow) -> int: ...
    @overload
    def Update(self, dataRows: List[System.Data.DataRow]) -> int: ...
    @overload
    def Update(
        self,
        p1: str,
        p2: str,
        p3: str,
        p4: float,
        p5: Optional[float],
        p6: Optional[bool],
        p7: Optional[bool],
        p8: str,
        p9: str,
        p10: str,
        p11: str,
        p12: str,
        p13: str,
        p14: Optional[int],
        p15: str,
        p16: str,
        p17: Optional[System.DateTime],
        p18: Optional[System.DateTime],
        p19: Optional[System.DateTime],
        p20: Optional[float],
        p21: int,
    ) -> int: ...
    def GetData(self) -> CDBDataSet.CompoundsDataTable: ...
    def Insert(
        self,
        p1: str,
        p2: str,
        p3: str,
        p4: float,
        p5: Optional[float],
        p6: Optional[bool],
        p7: Optional[bool],
        p8: str,
        p9: str,
        p10: str,
        p11: str,
        p12: str,
        p13: str,
        p14: Optional[int],
        p15: str,
        p16: str,
        p17: Optional[System.DateTime],
        p18: Optional[System.DateTime],
        p19: Optional[System.DateTime],
        p20: Optional[float],
    ) -> int: ...
    def Delete(self, p1: int) -> int: ...
    def Fill(self, dataTable: CDBDataSet.CompoundsDataTable) -> int: ...

class LibraryTableAdapter(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.ComponentModel.Component,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ClearBeforeFill: bool

    @overload
    def Update(self, dataTable: CDBDataSet.LibraryDataTable) -> int: ...
    @overload
    def Update(self, dataSet: CDBDataSet) -> int: ...
    @overload
    def Update(self, dataRow: System.Data.DataRow) -> int: ...
    @overload
    def Update(self, dataRows: List[System.Data.DataRow]) -> int: ...
    @overload
    def Update(
        self,
        p1: str,
        p2: str,
        p3: str,
        p4: str,
        p5: str,
        p6: Optional[int],
        p7: Optional[int],
        p8: Optional[bool],
        p9: Optional[System.DateTime],
        p10: Optional[System.DateTime],
        p11: int,
    ) -> int: ...
    def GetData(self) -> CDBDataSet.LibraryDataTable: ...
    def Insert(
        self,
        p1: str,
        p2: str,
        p3: str,
        p4: str,
        p5: str,
        p6: Optional[int],
        p7: Optional[int],
        p8: Optional[bool],
        p9: Optional[System.DateTime],
        p10: Optional[System.DateTime],
    ) -> int: ...
    def Delete(self, p1: int) -> int: ...
    def Fill(self, dataTable: CDBDataSet.LibraryDataTable) -> int: ...

class SpectraTableAdapter(
    System.IDisposable,
    System.ComponentModel.IComponent,
    System.ComponentModel.Component,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self) -> None: ...

    ClearBeforeFill: bool

    @overload
    def Update(self, dataTable: CDBDataSet.SpectraDataTable) -> int: ...
    @overload
    def Update(self, dataSet: CDBDataSet) -> int: ...
    @overload
    def Update(self, dataRow: System.Data.DataRow) -> int: ...
    @overload
    def Update(self, dataRows: List[System.Data.DataRow]) -> int: ...
    @overload
    def Update(
        self,
        p1: int,
        p2: str,
        p3: str,
        p4: Optional[float],
        p5: Optional[float],
        p6: Optional[float],
        p7: Optional[float],
        p8: Optional[float],
        p9: str,
        p10: str,
        p11: str,
        p12: Optional[int],
        p13: str,
        p14: Optional[System.DateTime],
        p15: Optional[System.DateTime],
        p16: str,
        p17: int,
        p18: int,
    ) -> int: ...
    @overload
    def Update(
        self,
        p2: str,
        p3: str,
        p4: Optional[float],
        p5: Optional[float],
        p6: Optional[float],
        p7: Optional[float],
        p8: Optional[float],
        p9: str,
        p10: str,
        p11: str,
        p12: Optional[int],
        p13: str,
        p14: Optional[System.DateTime],
        p15: Optional[System.DateTime],
        p16: str,
        p17: int,
        p18: int,
    ) -> int: ...
    def GetData(self) -> CDBDataSet.SpectraDataTable: ...
    def Insert(
        self,
        p1: int,
        p2: str,
        p3: str,
        p4: Optional[float],
        p5: Optional[float],
        p6: Optional[float],
        p7: Optional[float],
        p8: Optional[float],
        p9: str,
        p10: str,
        p11: str,
        p12: Optional[int],
        p13: str,
        p14: Optional[System.DateTime],
        p15: Optional[System.DateTime],
        p16: str,
    ) -> int: ...
    def Delete(self, p1: int, p2: int) -> int: ...
    def Fill(self, dataTable: CDBDataSet.SpectraDataTable) -> int: ...

class TableAdapterUtils:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CreateParamater() -> Any: ...
    @staticmethod
    def GetSelectCommand(
        columnMappings: System.Data.Common.DataColumnMappingCollection, tableName: str
    ) -> str: ...
    @staticmethod
    def GetUpdateCommand() -> Any: ...
    @staticmethod
    def GetInsertCommand() -> Any: ...
    @staticmethod
    def GetIndexOfParameter() -> Any: ...
